@@ -2,7 +2,7 @@
 sentry.plugins.sentry_urls.models
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 import sentry
@@ -16,7 +16,7 @@ from sentry.plugins.bases.tag import TagPlugin
 class UrlsPlugin(TagPlugin):
     """
     Automatically adds the 'url' tag from events containing interface data
-    from ``sentry.interfaes.Http``.
+    from ``sentry.interfaces.Http``.
     """
     slug = 'urls'
     title = _('Auto Tag: URLs')
